@@ -145,6 +145,9 @@ class ChEMBLTargetActivityProvider(StashableBase):
     def getTargetActivityDataPath(self):
         return os.path.join(self.__dirPath, "chembl-target-activity-data.json")
 
+    def reload(self):
+        self.__aD, self.__allIdD = self.__reload(self.__dirPath, True)
+
     def __reload(self, dirPath, useCache):
         startTime = time.time()
         aD = {}
@@ -376,6 +379,7 @@ class ChEMBLTargetActivityProvider(StashableBase):
         numToProcess = len(idList)
         allIdL = []
         logger.info("Filtered target list (%d)", numToProcess)
+        ok = numToProcess == 0
         try:
             for ii in range(0, len(idList), chunkSize):
                 logger.info("Begin outer chunk at ii %d (total targets %d)", ii, numToProcess)
