@@ -45,14 +45,14 @@ class ChEMBLTargetCofactorProvider(StashableBase):
         else:
             return False
 
-    def hasCofactor(self, rcsbEntityId):
+    def hasTarget(self, rcsbEntityId):
         return rcsbEntityId.upper() in self.__fD["cofactors"]
 
-    def getCofactors(self, rcsbEntityId):
+    def getTargets(self, rcsbEntityId):
         try:
             return self.__fD["cofactors"][rcsbEntityId.upper()]
         except Exception:
-            return None
+            return []
 
     def __getCofactorDataPath(self):
         return os.path.join(self.__dirPath, "ChEMBL-cofactor-data.json")
